@@ -51,8 +51,6 @@ static struct {
 	GtkWidget *dropherebox;
 	GtkWidget *filebox;
 
-	GtkWidget *aboutdialog;
-
 	gchar *exportpath;
 } droplist;
 
@@ -106,8 +104,6 @@ void droplist_init_gui ()
 		}
 	}
 
-	droplist.aboutdialog = glade_xml_get_widget (xml, "AboutDialog");
-
 	GtkListStore *liststore = gtk_list_store_new (NUM_COLS,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
 	droplist.store = liststore;
@@ -498,10 +494,11 @@ void droplist_export ()
 			GTK_FILE_CHOOSER (chooser), TRUE);
 	#endif
 
-	if (droplist.exportpath)
+	if (droplist.exportpath) {
+		g_message ("Using exportpath '%s'\n", droplist.exportpath);
 		gtk_file_chooser_set_current_folder (
 			GTK_FILE_CHOOSER (chooser), droplist.exportpath);
-	else {
+	} else {
 		// Go to the folder of the first file in the list
 		GtkTreeIter it;
 		GtkTreeModel *model = GTK_TREE_MODEL (droplist.store);
@@ -556,7 +553,7 @@ void droplist_export ()
 		}
 
 		gchar *basename = g_path_get_basename (filename);
-		gchar *extension = strchr (basename, '.');
+		gchar *extension = strrchr (basename, '.');
 		if (extension == NULL) {
 			// Append appropriate extension because the filename has no extension
 			char *strtmp;
@@ -580,11 +577,11 @@ void droplist_export ()
 		droplist_handle_plot (&data, TRUE, filename, format);
 		droplist_freedata (&data);
 
-		g_free (filename);
-
 		if (droplist.exportpath)
 			g_free (droplist.exportpath);
 		droplist.exportpath = g_path_get_dirname (filename);
+
+		g_free (filename);
 	}
 
 	gtk_widget_destroy (chooser);
@@ -777,7 +774,7 @@ void droplist_extra_help (GtkWidget *widg, gpointer data)
 		"<b><big>Using extra commands</big></b>\n\n"
 		"The commands entered here are executed by gnuplot after plotdrop "
 		"sets up the environment according to the requested settings, but "
-		"before the plot command itself.  Thus, for example, if you select the "
+		"before the plot command itself.  For example, if you select the "
 		"\"Lines\" appearance and put \"set style data points\" here, then "
 		"the resulting plot will be with points rather than lines."
 		);
@@ -854,17 +851,35 @@ gboolean droplist_really_quit ()
 void droplist_about ()
 {
 #if GTK_MINOR_VERSION >= 6
+	GtkWidget *aboutdialog = gtk_about_dialog_new ();
+
+	gtk_about_dialog_set_name (GTK_ABOUT_DIALOG (aboutdialog),
+		"PlotDrop");
+
+	gtk_about_dialog_set_comments (GTK_ABOUT_DIALOG (aboutdialog),
+		"A GNOME frontend to gnuplot, for simple graph plotting");
+
+	gtk_about_dialog_set_copyright (GTK_ABOUT_DIALOG (aboutdialog),
+		"Copyright © 2005 John Spray");
+
+	gtk_about_dialog_set_website (GTK_ABOUT_DIALOG (aboutdialog),
+		"http://icculus.org/~jcspray/plotdrop/");
+	gtk_about_dialog_set_website_label (GTK_ABOUT_DIALOG (aboutdialog),
+		"http://icculus.org/~jcspray/plotdrop/");
+
 	gchar *extrastring = g_strdup_printf (
 		"%s\nUsing gnuplot version %s",
-		gtk_about_dialog_get_comments (GTK_ABOUT_DIALOG (droplist.aboutdialog)),
+		gtk_about_dialog_get_comments (GTK_ABOUT_DIALOG (aboutdialog)),
 		gnuplot_get_version ());
 	gtk_about_dialog_set_comments (
-		GTK_ABOUT_DIALOG (droplist.aboutdialog), extrastring);
+		GTK_ABOUT_DIALOG (aboutdialog), extrastring);
 
 	gtk_about_dialog_set_version (
-		GTK_ABOUT_DIALOG (droplist.aboutdialog), VERSION);
+		GTK_ABOUT_DIALOG (aboutdialog), VERSION);
 
-	gtk_dialog_run (GTK_DIALOG (droplist.aboutdialog));
+	gtk_dialog_run (GTK_DIALOG (aboutdialog));
+
+	gtk_widget_destroy (aboutdialog);
 #endif
 }
 
@@ -894,8 +909,6 @@ void droplist_add_file_UI ()
 	}
 
 	if (gtk_dialog_run (GTK_DIALOG (chooser)) == GTK_RESPONSE_ACCEPT) {
-		/*droplist_add_file (
-			gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (chooser)));*/
 		GSList *files = gtk_file_chooser_get_filenames (GTK_FILE_CHOOSER (chooser));
 		GSList *it = files;
 		while (it != NULL) {
